%bcond_without buildtex

%global jarname   rabbitmq-client

%global failjava  true
%global failjunit no
#global failjunit yes

Name:          rabbitmq-java-client
Version:       3.6.5
Release:       8%{?dist}
Summary:       Java Advanced Message Queue Protocol client library
License:       ASL 2.0 and GPLv2+ and MPLv1.1
URL:           http://www.rabbitmq.com/java-client.html
Source0:       http://www.rabbitmq.com/releases/%{name}/v%{version}/%{name}-%{version}.tar.gz

BuildArch:     noarch
BuildRequires: maven-local mvn(commons-cli:commons-cli) mvn(commons-io:commons-io) mvn(junit:junit)
BuildRequires: ant ant-junit
BuildRequires: java-headless
BuildRequires: python2-devel >= 2.6 python2-simplejson

%if 0%{?with buildtex}
BuildRequires: texi2html
BuildRequires: %{_bindir}/pdflatex
%endif

%if 0%{?fedora} || 0%{?rhel} > 7
# for tests execution
BuildRequires:  rabbitmq-server
BuildRequires:  hostname
BuildRequires:  procps-ng

Suggests:       rabbitmq-server
Suggests:       activemq
%endif


%description
The library allows Java code to interface to AMQP servers.
Please see the specification page for more information on AMQP
inter-operation and standards-conformance

You will need an AMQP server, such as our very own RabbitMQ server,
to use with the client library.


%package doc
Summary:       Documentation for %{name}
Requires:      %{name} = %{version}-%{release}

%description doc
This package contains additional documentation for %{name}.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.


%prep
%setup -q
find . -name "*.bat" -delete
find . -name "*.class" -delete
find . -name "*.jar" -print -delete
# use ant only
rm Makefile

ln -sf $(build-classpath commons-cli) lib/
ln -sf $(build-classpath commons-io) lib/
ln -sf $(build-classpath junit) lib/

# Disable Spring bundlor support
sed -i "s|, bundlor.do||" build.xml
sed -i "s|, test-bundlor.do||" build.xml

#sed -i 's,\(\"jar.name\" value=\"\).*\",\1%{jarname}\",' build.xml
sed -i 's,\(\"haltOnFailureJunit\" value=\"\).*\",\1%{failjunit}\",' build.xml
sed -i 's,\(\"haltOnFailureJava\" value=\"\).*\",\1%{failjava}\",' build.xml

%mvn_file com.rabbitmq:amqp-client %{name} %{jarname} amqp-client


%build
%ant -Dimpl.version=%{version} -Dpython.bin=%{__python2} maven-bundle

# distribute documentation
cd doc/channels
%if 0%{?with buildtex}
find . -name \*.tex -print -exec 'texi2html {} ; pdflatex {}' \; -delete
%endif
find . -not -name channels.\* -delete


%install
%mvn_artifact build/bundle/amqp-client-%{version}.pom build/bundle/amqp-client-%{version}.jar
%mvn_install -J build/doc/api


%check
ant test-jar

#ant test-suite
#ant -Dtest=testDoubleDeletionExchange test-single
ant test-server

# client tests need a mock server, ugly hackery :)
export RABBITMQ_LOG_BASE=.
export RABBITMQ_MNESIA_BASE=.
%{_prefix}/lib/rabbitmq/bin/rabbitmq-server start -detached
pgrep -cf rabbitmq_server && ant test-client

# FIXME functional tests failure ahead!
#ant test-functional
#ant test-functional-and-server-with-ha

pkill -f rabbitmq_server ||:


%files -f .mfiles
%license LICENSE*
%doc README*

%files doc
%doc doc/*

%files javadoc -f .mfiles-javadoc
%license LICENSE*


%changelog
* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.5-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 20 2018 Mikolaj Izdebski <mizdebsk@redhat.com> - 3.6.5-6
- Explicitly use python2 during build
- Resolves: rhbz#1537230

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun Mar 18 2018 Iryna Shcherbina <ishcherb@redhat.com> - 3.6.5-4
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Jan 22 2018 Merlin Mathesius <mmathesi@redhat.com> - 3.6.5-2
- v3.6.6 has never built successfully since the spec file was updated
  to use it. v3.6.6 also changed the way the package would need to build,
  so fixing FTBFS by rolling back to v3.6.5. (BZ#1537230)

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Dec 10 2016 Raphael Groner <projects.rg@smart.ms> - 3.6.6-1
- new version

* Tue Sep 27 2016 Raphael Groner <projects.rg@smart.ms> - 3.6.5-1
- new version

* Sat Aug 06 2016 Raphael Groner <projects.rg@smart.ms> - 3.6.3-2
- rebuilt (erlang)

* Sun Jul 10 2016 Raphael Groner <projects.rg@smart.ms> - 3.6.3-1
- new version

* Sun Jul 03 2016 Raphael Groner <projects.rg@smart.ms> - 3.6.2-2
- fix execution of client tests with running rabbitmq-server

* Thu May 19 2016 Raphael Groner <projects.rg@smart.ms> - 3.6.2-1
- new version

* Fri Mar 25 2016 Raphael Groner <projects.rg@smart.ms> - 3.6.1-3
- bump release for rebuild

* Fri Mar 25 2016 Raphael Groner <projects.rg@smart.ms> - 3.6.1-2
- fix tests execution, properly stop mocked server

* Tue Mar 01 2016 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 3.6.1-1
- Update to 3.6.1 (#1313412)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 08 2016 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 3.6.0-1
- Update to 3.6.0 (#1296745)

* Wed Oct 28 2015 Raphael Groner <projects.rg@smart.ms> - 3.5.6-1
- v3.5.6, rhbz#1270088

* Sat Sep 26 2015 Raphael Groner <projects.rg@smart.ms> - 3.5.5-1
- v3.5.5 (rhbz#1266284)

* Mon Jul 27 2015 Raphael Groner <projects.rg@smart.ms> - 3.5.4-1
- v3.5.4 (rhbz#1245851)
- enable weak dependencies
- use build conditional for tex

* Fri May 22 2015 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 3.5.3-1
- Update to 3.5.3 (#1221420)

* Tue Mar 24 2015 Raphael Groner <projects.rg@smart.ms> - 3.5.0-1
- v3.5.0

* Sun Feb 22 2015 Raphael Groner (Builder) <projects.rg@smart.ms> - 3.4.4-1
- new upstream release v3.4.4 (rhbz#1195018)

* Wed Jan 28 2015 Raphael Groner <projects.rg (AT) smart.ms> - 3.4.2-5
- introduce license macro

* Thu Dec 11 2014 Raphael Groner <projects.rg [AT] smart.ms> - 3.4.2-4
- fix documentation again

* Thu Dec 11 2014 Raphael Groner <projects.rg [AT] smart.ms> - 3.4.2-3
- fix documentation

* Wed Dec 10 2014 Raphael Groner <projects.rg [AT] smart.ms> - 3.4.2-2
- documentation subpackage

* Wed Dec 10 2014 Raphael Groner <projects.rg [AT] smart.ms> - 3.4.2-1
- maven contributions from puntogil
- update to 3.4.2

* Tue Nov 25 2014 Raphael Groner <projects.rg [AT] smart.ms> - 3.4.1-1
- update to 3.4.1

* Wed Jun 11 2014 gil cattaneo <puntogil@libero.it> 3.3.2-1
- initial rpm
